==> gnucash-2.2.9-i486-2gv.txz: install/doinst.sh <==
#Added by slkbuild 0.7.0
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
dotnew etc/gnucash/config
( cd usr/share/gnucash ; rm -rf gnome )
( cd usr/share/gnucash ; ln -sf ../gnome gnome )
( cd usr/lib ; rm -rf libgnc-qof.so.1 )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so.1 )
( cd usr/lib ; rm -rf libgnc-qof.so )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so )
( cd usr/lib ; rm -rf libgnc-core-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-core-utils.so )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so )
( cd usr/lib ; rm -rf libgnc-module.so.0 )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so.0 )
( cd usr/lib ; rm -rf libgnc-module.so )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so )
( cd usr/lib ; rm -rf libgnc-backend-file-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-file-utils.so.0.0.0 libgnc-backend-file-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-backend-file-utils.so )
( cd usr/lib ; ln -sf libgnc-backend-file-utils.so.0.0.0 libgnc-backend-file-utils.so )
( cd usr/lib ; rm -rf libgnc-gnome.so.0 )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so.0 )
( cd usr/lib ; rm -rf libgnc-gnome.so )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so )
( cd usr/lib ; rm -rf libgnc-business-ledger.so.0 )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so.0 )
( cd usr/lib ; rm -rf libgnc-business-ledger.so )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so )

==> gnucash-2.4.3-i486-1gv.txz: install/doinst.sh <==
( cd usr/share/gnucash ; rm -rf gnome )
( cd usr/share/gnucash ; ln -sf ../gnome gnome )
( cd usr/lib ; rm -rf libgnc-qof.so.1 )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so.1 )
( cd usr/lib ; rm -rf libgnc-qof.so )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so )
( cd usr/lib ; rm -rf libgnc-core-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-core-utils.so )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so )
( cd usr/lib ; rm -rf libgnc-module.so.0 )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so.0 )
( cd usr/lib ; rm -rf libgnc-module.so )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so )
( cd usr/lib ; rm -rf libgnc-backend-xml-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-xml-utils.so.0.0.0 libgnc-backend-xml-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-backend-xml-utils.so )
( cd usr/lib ; ln -sf libgnc-backend-xml-utils.so.0.0.0 libgnc-backend-xml-utils.so )
( cd usr/lib ; rm -rf libgnc-backend-sql.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-sql.so.0.0.0 libgnc-backend-sql.so.0 )
( cd usr/lib ; rm -rf libgnc-backend-sql.so )
( cd usr/lib ; ln -sf libgnc-backend-sql.so.0.0.0 libgnc-backend-sql.so )
( cd usr/lib ; rm -rf libgnc-gnome.so.0 )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so.0 )
( cd usr/lib ; rm -rf libgnc-gnome.so )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so )
( cd usr/lib ; rm -rf libgnc-business-ledger.so.0 )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so.0 )
( cd usr/lib ; rm -rf libgnc-business-ledger.so )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so )

#Added by slkbuild 0.8.5
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
dotnew etc/gnucash/config
